@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -20,9 +19,7 @@ updated the Document, it is used to service the user session.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -30,16 +27,11 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from abc import ABCMeta, abstractmethod, abstractproperty
-
-# External imports
-from tornado import gen
+from abc import ABCMeta, abstractmethod
 
 # Bokeh imports
 from ..document import Document
 from ..settings import settings
-from ..util.future import with_metaclass
-from ..util.tornado import yield_for_all_futures
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -101,7 +93,7 @@ class Application(object):
         metadata = kwargs.pop('metadata', None)
         if kwargs:
             raise TypeError("Invalid keyword argument: %s" %
-                kwargs.keys()[0])
+                list(kwargs.keys())[0])
         self._static_path = None
         self._handlers = []
         self._metadata = metadata
@@ -208,8 +200,7 @@ class Application(object):
         for h in self._handlers:
             h.on_server_unloaded(server_context)
 
-    @gen.coroutine
-    def on_session_created(self, session_context):
+    async def on_session_created(self, session_context):
         ''' Invoked to execute code when a new session is created.
 
         This method calls ``on_session_created`` on each handler, in order,
@@ -220,12 +211,10 @@ class Application(object):
 
         '''
         for h in self._handlers:
-            result = h.on_session_created(session_context)
-            yield yield_for_all_futures(result)
-        raise gen.Return(None)
+            await h.on_session_created(session_context)
+        return None
 
-    @gen.coroutine
-    def on_session_destroyed(self, session_context):
+    async def on_session_destroyed(self, session_context):
         ''' Invoked to execute code when a session is destroyed.
 
         This method calls ``on_session_destroyed`` on each handler, in order,
@@ -235,11 +224,27 @@ class Application(object):
 
         '''
         for h in self._handlers:
-            result = h.on_session_destroyed(session_context)
-            yield yield_for_all_futures(result)
-        raise gen.Return(None)
+            await h.on_session_destroyed(session_context)
+        return None
 
-class ServerContext(with_metaclass(ABCMeta)):
+    def process_request(self, request):
+        ''' Processes incoming HTTP request returning a dictionary of
+        additional data to add to the session_context.
+
+        Args:
+            request: HTTP request
+
+        Returns:
+            A dictionary of JSON serializable data to be included on
+            the session context.
+        '''
+        request_data = {}
+        for h in self._handlers:
+            request_data.update(h.process_request(request))
+        return request_data
+
+
+class ServerContext(metaclass=ABCMeta):
     ''' A harness for server-specific information and tasks related to
     collections of Bokeh sessions.
 
@@ -249,7 +254,8 @@ class ServerContext(with_metaclass(ABCMeta)):
 
     # Properties --------------------------------------------------------------
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def sessions(self):
         ''' ``SessionContext`` instances belonging to this application.
 
@@ -361,7 +367,7 @@ class ServerContext(with_metaclass(ABCMeta)):
         '''
         pass
 
-class SessionContext(with_metaclass(ABCMeta)):
+class SessionContext(metaclass=ABCMeta):
     ''' A harness for server-specific information and tasks related to
     Bokeh sessions.
 
@@ -378,7 +384,8 @@ class SessionContext(with_metaclass(ABCMeta)):
 
     # Properties --------------------------------------------------------------
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def destroyed(self):
         ''' If ``True``, the session has been discarded and cannot be used.
 
