@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -13,23 +12,17 @@ and smooths some compatibility issues.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
-# Standard library imports
-
 # External imports
-from tornado import gen, locks
+from tornado import locks
 from tornado.websocket import WebSocketError
 
-# Bokeh imports
-
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -59,8 +52,7 @@ class WebSocketClientConnectionWrapper(object):
 
     # Internal methods --------------------------------------------------------
 
-    @gen.coroutine
-    def write_message(self, message, binary=False, locked=True):
+    async def write_message(self, message, binary=False, locked=True):
         ''' Write a message to the websocket after obtaining the appropriate
         Bokeh Document lock.
 
@@ -77,11 +69,11 @@ class WebSocketClientConnectionWrapper(object):
 
             future = self._socket.write_message(message, binary)
 
-            # don't yield this future or we're blocking on ourselves!
-            raise gen.Return(future)
+            # don't await this future or we're blocking on ourselves!
+            return future
 
         if locked:
-            with (yield self.write_lock.acquire()):
+            with await self.write_lock.acquire():
                 write_message_unlocked()
         else:
             write_message_unlocked()
