@@ -203,6 +203,8 @@ class LegendItem(Model):
 class Legend(Annotation):
     ''' Render informational legends for a plot.
 
+    See :ref:`userguide_plotting_legends` for information on plotting legends.
+
     '''
 
     location = Either(Enum(LegendLocation), Tuple(Float, Float), default="top_right", help="""
@@ -335,6 +337,8 @@ class Legend(Annotation):
 class ColorBar(Annotation):
     ''' Render a color bar based on a color mapper.
 
+    See :ref:`userguide_plotting_color_bars` for information on plotting color bars.
+
     '''
 
     location = Either(Enum(LegendLocation), Tuple(Float, Float),
@@ -459,7 +463,7 @@ class ColorBar(Annotation):
     main plot area.
     """)
 
-    bar_props = Include(LineProps, help="""
+    bar_props = Include(ScalarLineProps, help="""
     The %s for the color scale bar outline.
     """)
 
@@ -482,6 +486,8 @@ class ColorBar(Annotation):
 class Arrow(Annotation):
     ''' Render arrows as an annotation.
 
+    See :ref:`userguide_plotting_arrows` for information on plotting arrows.
+
     '''
 
     x_start = NumberSpec(help="""
@@ -539,6 +545,8 @@ class Arrow(Annotation):
 class BoxAnnotation(Annotation):
     ''' Render a shaded rectangular region as an annotation.
 
+    See :ref:`userguide_plotting_box_annotations` for information on plotting box annotations.
+
     '''
 
     left = Either(Auto, NumberSpec(), default=None, help="""
@@ -619,6 +627,9 @@ class BoxAnnotation(Annotation):
     Specifies whether the box is rendered as a canvas element or as an
     css element overlaid on the canvas. The default mode is "canvas".
 
+    .. note:
+        This property is deprecated and will be removed in bokeh 3.0.
+
     .. warning::
         The line_dash and line_dash_offset attributes aren't supported if
         the render_mode is set to "css"
@@ -628,6 +639,8 @@ class BoxAnnotation(Annotation):
 class Band(Annotation):
     ''' Render a filled area band along a dimension.
 
+    See :ref:`userguide_plotting_bands` for information on plotting bands.
+
     '''
     lower = PropertyUnitsSpec(default=None, units_type=Enum(SpatialUnits), units_default="data", help="""
     The coordinates of the lower portion of the filled area band.
@@ -692,6 +705,8 @@ class Label(TextAnnotation):
     appearance of the text, its background, as well as the rectangular bounding
     box border.
 
+    See :ref:`userguide_plotting_labels` for information on plotting labels.
+
     '''
 
     x = Float(help="""
@@ -929,6 +944,8 @@ class PolyAnnotation(Annotation):
 class Slope(Annotation):
     """ Render a sloped line as an annotation.
 
+    See :ref:`userguide_plotting_slope` for information on plotting slopes.
+
     """
 
     gradient = Float(help="""
@@ -956,6 +973,8 @@ class Slope(Annotation):
 class Span(Annotation):
     """ Render a horizontal or vertical line span.
 
+    See :ref:`userguide_plotting_spans` for information on plotting spans.
+
     """
 
     location = Float(help="""
@@ -989,6 +1008,9 @@ class Span(Annotation):
     Specifies whether the span is rendered as a canvas element or as a
     CSS element overlaid on the canvas. The default mode is "canvas".
 
+    .. note:
+        This property is deprecated and will be removed in bokeh 3.0.
+
     .. warning::
         The line_dash and line_dash_offset attributes aren't supported if
         the render_mode is set to "css"
@@ -1002,6 +1024,8 @@ class Span(Annotation):
 class Title(TextAnnotation):
     ''' Render a single title box as an annotation.
 
+    See :ref:`userguide_plotting_titles` for information on plotting titles.
+
     '''
 
     text = String(help="""
@@ -1113,6 +1137,8 @@ class Tooltip(Annotation):
 class Whisker(Annotation):
     ''' Render a whisker along a dimension.
 
+    See :ref:`userguide_plotting_whiskers` for information on plotting whiskers.
+
     '''
 
     lower = PropertyUnitsSpec(default=None, units_type=Enum(SpatialUnits), units_default="data", help="""
