@@ -39,7 +39,11 @@ from ..core.properties import (
     Tuple,
 )
 from ..core.validation import error, warning
-from ..core.validation.errors import MIN_PREFERRED_MAX_HEIGHT, MIN_PREFERRED_MAX_WIDTH
+from ..core.validation.errors import (
+    MIN_PREFERRED_MAX_HEIGHT,
+    MIN_PREFERRED_MAX_WIDTH,
+    REPEATED_LAYOUT_CHILD,
+)
 from ..core.validation.warnings import (
     BOTH_CHILD_AND_ROOT,
     EMPTY_LAYOUT,
@@ -116,6 +120,9 @@ class LayoutDOM(Model):
 
     margin = Tuple(Int, Int, Int, Int, default=(0, 0, 0, 0), help="""
     Allows to create additional space around the component.
+    The values in the tuple are ordered as follows - Margin-Top, Margin-Right, Margin-Bottom and Margin-Left,
+    similar to CSS standards.
+    Negative margin values may be used to shrink the space from any direction.
     """).accepts(Tuple(Int, Int), lambda v_h: (v_h[0], v_h[1], v_h[0], v_h[1])) \
         .accepts(Int, lambda m: (m, m, m, m))
 
@@ -352,6 +359,12 @@ class GridBox(LayoutDOM):
     respectively.
     """)
 
+    @error(REPEATED_LAYOUT_CHILD)
+    def _check_repeated_layout_children(self):
+        children = [ child[0] for child in self.children ]
+        if len(children) != len(set(children)):
+            return str(self)
+
 @abstract
 class Box(LayoutDOM):
     ''' Abstract base class for Row and Column. Do not use directly.
@@ -384,6 +397,11 @@ class Box(LayoutDOM):
         else:
             return None
 
+    @error(REPEATED_LAYOUT_CHILD)
+    def _check_repeated_layout_children(self):
+        if len(self.children) != len(set(self.children)):
+            return str(self)
+
     children = List(Instance(LayoutDOM), help="""
     The list of children, which can be other components including plots, rows, columns, and widgets.
     """)
