@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,9 +11,7 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -21,18 +19,27 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from datetime import datetime, date
 import numbers
-
-# External imports
+from datetime import date, datetime
 
 # Bokeh imports
 from ...core.has_props import abstract
-from ...core.properties import Bool, Int, Float, String, Date, Enum, Tuple, Instance, Color, Override
-from ...core.enums import SliderCallbackPolicy
+from ...core.properties import (
+    Bool,
+    Color,
+    Datetime,
+    Either,
+    Enum,
+    Float,
+    Instance,
+    Int,
+    Override,
+    String,
+    Tuple,
+)
 from ...core.validation import error
 from ...core.validation.errors import EQUAL_SLIDER_START_END
-from ..callbacks import Callback
+from ..formatters import TickFormatter
 from .widget import Widget
 
 #-----------------------------------------------------------------------------
@@ -59,7 +66,8 @@ class AbstractSlider(Widget):
         if 'start' in kwargs and 'end' in kwargs:
             if kwargs['start'] == kwargs['end']:
                 raise ValueError("Slider 'start' and 'end' cannot be equal.")
-        super(Widget, self).__init__(**kwargs)
+
+        super().__init__(**kwargs)
 
     title = String(default="", help="""
     Slider's label.
@@ -69,7 +77,7 @@ class AbstractSlider(Widget):
     Whether or not show slider's value.
     """)
 
-    format = String(help="""
+    format = Either(String, Instance(TickFormatter), help="""
     """)
 
     direction = Enum("ltr", "rtl", help="""
@@ -78,27 +86,6 @@ class AbstractSlider(Widget):
     tooltips = Bool(default=True, help="""
     """)
 
-    callback = Instance(Callback, help="""
-    A callback to run in the browser whenever the current Slider value changes.
-    """)
-
-    callback_throttle = Float(default=200, help="""
-    Number of milliseconds to pause between callback calls as the slider is moved.
-    """)
-
-    callback_policy = Enum(SliderCallbackPolicy, default="throttle", help="""
-    When the callback is initiated. This parameter can take on only one of three options:
-
-    * "continuous": the callback will be executed immediately for each movement of the slider
-    * "throttle": the callback will be executed at most every ``callback_throttle`` milliseconds.
-    * "mouseup": the callback will be executed only once when the slider is released.
-
-    The "mouseup" policy is intended for scenarios in which the callback is expensive in time.
-
-    .. warning::
-        Callback policy currently apply to JS callbacks
-    """)
-
     bar_color = Color(default="#e6e6e6", help="""
     """)
 
@@ -127,6 +114,10 @@ class Slider(AbstractSlider):
     Initial or selected value.
     """)
 
+    value_throttled = Float(help="""
+    Initial or selected value, throttled according to report only on mouseup.
+    """)
+
     step = Float(default=1, help="""
     The step between consecutive values.
     """)
@@ -140,6 +131,10 @@ class RangeSlider(AbstractSlider):
     Initial or selected range.
     """)
 
+    value_throttled = Tuple(Float, Float, help="""
+    Initial or selected value, throttled according to report only on mouseup.
+    """)
+
     start = Float(help="""
     The minimum allowable value.
     """)
@@ -157,15 +152,48 @@ class RangeSlider(AbstractSlider):
 class DateSlider(AbstractSlider):
     """ Slider-based date selection widget. """
 
-    value = Date(help="""
+    @property
+    def value_as_datetime(self):
+        ''' Convenience property to retrieve the value as a datetime object.
+
+        Added in version 2.0
+        '''
+        if self.value is None:
+            return None
+
+        if isinstance(self.value, numbers.Number):
+            return datetime.utcfromtimestamp(self.value / 1000)
+
+        return self.value
+
+    @property
+    def value_as_date(self):
+        ''' Convenience property to retrieve the value as a date object.
+
+        Added in version 2.0
+        '''
+        if self.value is None:
+            return None
+
+        if isinstance(self.value, numbers.Number):
+            dt = datetime.utcfromtimestamp(self.value / 1000)
+            return date(*dt.timetuple()[:3])
+
+        return self.value
+
+    value = Datetime(help="""
     Initial or selected value.
     """)
 
-    start = Date(help="""
+    value_throttled = Datetime(help="""
+    Initial or selected value, throttled to report only on mouseup.
+    """)
+
+    start = Datetime(help="""
     The minimum allowable value.
     """)
 
-    end = Date(help="""
+    end = Datetime(help="""
     The maximum allowable value.
     """)
 
@@ -183,6 +211,7 @@ class DateRangeSlider(AbstractSlider):
         ''' Convenience property to retrieve the value tuple as a tuple of
         datetime objects.
 
+        Added in version 1.1
         '''
         if self.value is None:
             return None
@@ -195,7 +224,7 @@ class DateRangeSlider(AbstractSlider):
             d2 = datetime.utcfromtimestamp(v2 / 1000)
         else:
             d2 = v2
-        return d1, d2    \
+        return d1, d2
 
     @property
     def value_as_date(self):
@@ -219,15 +248,19 @@ class DateRangeSlider(AbstractSlider):
             d2 = v2
         return d1, d2
 
-    value = Tuple(Date, Date, help="""
+    value = Tuple(Datetime, Datetime, help="""
     Initial or selected range.
     """)
 
-    start = Date(help="""
+    value_throttled = Tuple(Datetime, Datetime, help="""
+    Initial or selected value, throttled to report only on mouseup.
+    """)
+
+    start = Datetime(help="""
     The minimum allowable value.
     """)
 
-    end = Date(help="""
+    end = Datetime(help="""
     The maximum allowable value.
     """)
 
