@@ -165,6 +165,10 @@ class TestClientServer(object):
     async def test_allow_websocket_origin(self, ManagedServerLoop) -> None:
         application = Application()
 
+        # allow good local origin with random port
+        with ManagedServerLoop(application, port=0) as server:
+            await self.check_http_ok_socket_ok(server, origin="http://localhost:%s" % server.port)
+
         # allow good origin
         with ManagedServerLoop(application, allow_websocket_origin=["example.com"]) as server:
             await self.check_http_ok_socket_ok(server, origin="http://example.com:80")
